Welcome to iechelle's documentation!
===========================================================

`iechelle` is an interactive tool for Echelle diagram analysis and peakbagging in asteroseismology.

.. toctree::
   :maxdepth: 2
   :caption: User Guide:

   installation
   operation_manual
   tutorial

==================
Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
